@@ -1,4 +1,3 @@
-using namespace std;
 #if defined HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -9,11 +8,16 @@ using namespace std;
 #include <id3/tag.h>
 #include <getopt.h>
 #include <id3/misc_support.h>
+#ifdef WIN32
+#include <io.h>
+#define snprintf _snprintf
+#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#define VERSION_NUMBER "$Revision: 1.10 $"
+#include "genre.h"
+
 #define MAXNOFRAMES 1000
 
 #define TMPSIZE 255    
@@ -59,16 +63,7 @@ void PrintUsage(char *sName)
 void PrintVersion(char *sName)
 {
   size_t nIndex;
-  std::cout << sName << " ";
-  for (nIndex = 0; nIndex < strlen(VERSION_NUMBER); nIndex++)
-    if (VERSION_NUMBER[nIndex] == ' ') break;
-  nIndex++;
-  for (; nIndex < strlen (VERSION_NUMBER); nIndex++)
-  {
-    if (VERSION_NUMBER[nIndex] == ' ') break;
-    std::cout << VERSION_NUMBER[nIndex];
-  }
-  std::cout << std::endl;
+  std::cout << sName << " " << VERSION << std::endl;
   std::cout << "Uses " << ID3LIB_FULL_NAME << std::endl << std::endl;
 
   std::cout << "This program adds/modifies/removes/views id3v2 tags, " << std::endl 
@@ -83,6 +78,10 @@ extern void PrintGenreList();
 extern void DeleteTag(int argc, char *argv[], int optind, int whichTags); 
 extern void ConvertTag(int argc, char *argv[], int optind);
 
+#ifdef SORT_RUNTIME
+extern void InitGenres();
+#endif  // SORT_RUNTIME
+
 int main( int argc, char *argv[])
 {
   int iOpt;
@@ -224,7 +223,10 @@ int main( int argc, char *argv[])
 
     if (iOpt == 0) iOpt = iLongOpt;
 //    if (iOpt == 0) iOpt = optFrameID;
-    
+
+#ifdef SORT_RUNTIME
+    InitGenres();
+#endif  // SORT_RUNTIME
 
     switch (iOpt)
     {
@@ -280,10 +282,22 @@ int main( int argc, char *argv[])
                 frameCounter++;
                 break;
       case 'g': 
-                snprintf(tmp, TMPSIZE, "(%s)", optarg);
+          {
+                int genre_id = 255;
+                char *genre_str;
+                sscanf(optarg, "%d", &genre_id);
+                if (genre_id == 255)
+                    genre_id = GetNumFromGenre(optarg);
+                if (genre_id == 255)
+                    genre_str = optarg;
+                else {
+                    sprintf(tmp, "(%d)", genre_id);
+                    genre_str = tmp;
+                }
                 frameList[frameCounter].id   = ID3FID_CONTENTTYPE;
-                frameList[frameCounter].data = tmp;
+                frameList[frameCounter].data = genre_str;
                 frameCounter++;
+          }
                 break;
       case 'y': 
                 frameList[frameCounter].id   = ID3FID_YEAR;
