@@ -12,7 +12,6 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-using namespace std;
 #if defined HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -49,8 +48,8 @@ void PrintFrameHelp(char *sName)
 
 void PrintGenreList()
 {
-  for (int ii = 0; ii < genre_count; ii++)
-    printf("%3d: %s\n", ii, genre_table[ii]);
+  for (int ii = 0; ii < GetGenreCount(); ii++)
+    printf("%3d: %s\n", ii, GetGenreFromNum(ii));
 }
 
 int PrintInformation(char *sFileName, const ID3_Tag &myTag)
@@ -121,11 +120,17 @@ int PrintInformation(char *sFileName, const ID3_Tag &myTag)
         }
         case ID3FID_CONTENTTYPE:
         {
+          const char* genre_str;
+          int genre_id = 255;
           char *sText = ID3_GetString(myFrame, ID3FN_TEXT);
-          int tmp = 0;
-          sscanf(sText, "(%d)", &tmp);
-          std::cout << (tmp <= genre_count ? genre_table[tmp] : "Unknown") <<
-            " " << sText << std::endl;
+          sscanf(sText, "(%d)", &genre_id);
+          if (genre_id == 255) {
+            genre_str = sText;
+            genre_id = GetNumFromGenre(sText);
+          }
+          else
+            genre_str = GetGenreFromNum(genre_id);
+          std::cout << genre_str << " (" << genre_id << ")" << std::endl;
           delete [] sText;
           break;
         }
@@ -339,13 +344,13 @@ int PrintID3v1Tag(char *sFileName)
   
   if (!strncmp(id3v1tag.tag, "TAG", 3))
   {
-    std::cout << "id3v1 tag info for " << sFileName << ":" << endl;
+    std::cout << "id3v1 tag info for " << sFileName << ":" << std::endl;
     printf("Title  : %-30.30s  Artist: %-30.30s\n",
             id3v1tag.title, id3v1tag.artist);
     printf("Album  : %-30.30s  Year: %-4.4s, Genre: %s (%d)\n",
             id3v1tag.album, id3v1tag.year, 
-            (id3v1tag.genre < genre_count)
-            ? genre_table[id3v1tag.genre] : 
+            (id3v1tag.genre < GetGenreCount())
+            ? GetGenreFromNum(id3v1tag.genre) : 
             "Unknown", id3v1tag.genre);
     if (!id3v1tag.comment[28])
       printf("Comment: %-28.28s    Track: %d\n", 
